@@ -3,7 +3,7 @@ import json
 import time
 import requests
 from retry import retry
-from .exceptions import BadRequest, ScheduledMaintenance
+from .exceptions import BadRequestError, ScheduledMaintenanceError
 from .core import CentralReachCore
 
 
@@ -11,13 +11,13 @@ def retry_if_bad_request(func):
     attempt = 1
     tries = 3
 
-    @retry(exceptions=BadRequest, tries=tries, delay=1, backoff=2)
+    @retry(exceptions=BadRequestError, tries=tries, delay=1, backoff=2)
     def wrapper(*args, **kwargs):
         try:
             return func(*args, **kwargs)
-        except BadRequest as ex:
+        except BadRequestError as ex:
             nonlocal attempt
-            print(f'Bad request Attempt {attempt}. {str(ex)}', 'WARN')
+            print(f'Bad request Attempt {attempt}...', 'WARN')
             attempt = attempt + 1 if attempt < tries else 1
             raise ex
 
@@ -66,7 +66,7 @@ class CentralReachRequestsCore:
                        exc_message: str = '',
                        re_authorize: bool = True) -> None:
         """
-        This method check response and raise exception 'BadRequest' or 'ScheduledMaintenance' with exc_message,
+        This method check response and raise exception 'BadRequestError' or 'ScheduledMaintenanceError' with exc_message,
         If status code is 401 (unauthorized) then it will try login again
         :param response: response from request
         :param mandatory_json: bool, if True - it will check is response contain json data
@@ -76,20 +76,20 @@ class CentralReachRequestsCore:
         if self.__is_scheduled_maintenance(response):
             print(exc_message, 'Error')
             print("'Central Reach' site is currently unavailable due to scheduled maintenance", 'Error')
-            raise ScheduledMaintenance
+            raise ScheduledMaintenanceError
 
         elif re_authorize and response.status_code == 401:
             self._login_to_central_reach(self.__login, self.__password)
-            raise BadRequest(f"{exc_message}Status Code: {response.status_code} (Unauthorized request), "
+            raise BadRequestError(f"{exc_message}Status Code: {response.status_code} (Unauthorized request), "
                              f"Json content: {response.json()}, Headers: {response.headers}")
 
         if response.status_code != 200 or (mandatory_json and not self._is_json_response(response)):
             exc_message = exc_message + '\n' if exc_message else ''
             if self._is_json_response(response):
-                raise BadRequest(f"{exc_message}Status Code: {response.status_code}, "
+                raise BadRequestError(f"{exc_message}Status Code: {response.status_code}, "
                                  f"Json content: {response.json()}, Headers: {response.headers}")
             else:
-                raise BadRequest(f"{exc_message}Status Code: {response.status_code}, "
+                raise BadRequestError(f"{exc_message}Status Code: {response.status_code}, "
                                  f"Headers: {response.headers}")
 
     @retry_if_bad_request
@@ -107,11 +107,11 @@ class CentralReachRequestsCore:
                 # Check authorization
                 self.__insurance_eligibility_status()
                 break
-            except BadRequest:
+            except BadRequestError:
                 time.sleep(1)
                 continue
         else:
-            raise BadRequest("Session is unauthorized after login to Central Reach")
+            raise BadRequestError("Session is unauthorized after login to Central Reach")
         central_reach_core.browser.close_browser()
 
     def __insurance_eligibility_status(self) -> None:
