@@ -24,6 +24,9 @@ class QuickbooksCore(SitesCore):
     def send_message_invoice_added(self, manager: str, customer: str, invoice_number: str, total_rate: float) -> None:
         pass
 
+    def send_message_estimate_added(self, manager: str, customer: str, estimate_number: str, total_rate: float) -> None:
+        pass
+
     def login_to_site(self) -> bool:
         self.is_site_available = False
         self.browser.close_browser()
@@ -110,6 +113,17 @@ class QuickbooksCore(SitesCore):
             '//a[@data-id="invoice"]'
         ])
 
+    def open_add_estimate_page(self) -> None:
+        """
+        Open page 'Add estimate'
+        """
+        self.browser.go_to(f'{self.base_url}/app/homepage')
+
+        self.click_bunch_of_elements([
+            '//button[@data-id="global_create_button"]',
+            '//a[@data-id="estimate"]'
+        ])
+
     def open_invoices_page(self) -> None:
         """
         Check paid page
@@ -312,3 +326,149 @@ class QuickbooksCore(SitesCore):
             if 'Please use a different name' in error:
                 return True
         return False
+
+    def add_estimate(self, grouped_rows: list, is_prod: bool = False) -> (bool, str, str):
+        """
+        Returns the bool if the new estimate was created and sent.
+
+        :param grouped_rows: List of invoice data:
+            customer: Customer name, column Account from spreadsheet
+            service: Service name, column Service Type from spreadsheet
+            description: Description column from spreadsheet
+            rate: Amount column from spreadsheet
+            processing_fee: True if column 3% Markup from spreadsheet has value Yes
+        :param is_prod: If true bot will perform all change
+        :return: status (bool): Bool value indicate if new estimate was created and sent
+        """
+        self.open_add_estimate_page()
+
+        first_row: GroupedRow = grouped_rows[0]
+        customer: str = first_row.customer
+
+        self.wait_element('//input[@aria-label="Choose a customer"]')
+        self.browser.input_text('//input[@aria-label="Choose a customer"]', customer.replace('\\', '\\\\'))
+
+        self.wait_element(f'//span[text()="Add new"]/../span[text()="{customer}"]', 10, False)
+
+        xpath_customers: str = f'//div[@aria-label="Choose a customer"]/div[not(@aria-label)]//span[@class="mainLabel"]'
+        customers: list = self.browser.find_elements(xpath_customers)
+        if len(customers) > 1:
+            for i in range(3):
+                sleep(1)
+                customers: list = self.browser.find_elements(xpath_customers)
+                if len(customers) == 1:
+                    break
+        if not customers:
+            customers: list = self.browser.find_elements('//span[@class="dijitComboBoxHighlightMatch"]')
+
+        selected: bool = False
+        for customer_id in customers:
+            if str(customer_id.text).strip().lower() == customer.strip().lower():
+                self.browser.click_element_when_visible(customer_id)
+                selected = True
+                break
+        if not selected:
+            for customer_id in customers:
+                if customer.strip().lower() in str(customer_id.text).strip().lower():
+                    self.browser.click_element_when_visible(customer_id)
+                    selected = True
+                    break
+        if not selected:
+            self.browser.capture_page_screenshot(
+                os.path.join(
+                    self.output_folder,
+                    f'No_customer_{datetime.now().strftime("%H_%M_%S")}.png'
+                )
+            )
+            self.send_message_service_type_not_found(first_row.manager, customer)
+            return False, '', ''
+
+        index: int = 1
+        total_rate: float = 0.0
+        row: GroupedRow
+        for row in grouped_rows:
+            service: str = row.service
+            description: str = row.description
+            rate: float = row.rate
+            total_rate += rate
+
+            self.browser.click_element_when_visible(f'//td[text()="{index}"]')
+            self.wait_element('//input[contains(@id, "ItemComboBox") or @aria-label="ProductService"]')
+            self.browser.input_text('//input[contains(@id, "ItemComboBox") or @aria-label="ProductService"]', service)
+
+            self.wait_element(
+                f'//div[@class="name"]/span[text()="{service}" and @class="dijitComboBoxHighlightMatch"]', 5, False
+            )
+            if not self.does_element_displayed(f'//div[@class="name"]/span[text()="{service}" and @class="dijitComboBoxHighlightMatch"]'):
+                self.wait_element(f'//div/span/b[text()="{service}"]')
+                if not self.does_element_displayed(f'//div/span/b[text()="{service}"]'):
+                    self.browser.capture_page_screenshot(
+                        os.path.join(
+                            self.output_folder,
+                            f'No_service_{datetime.now().strftime("%H_%M_%S")}.png'
+                        )
+                    )
+                    self.send_message_service_type_not_found(first_row.manager, service)
+                    return False, '', ''
+                else:
+                    self.browser.click_element_when_visible(f'//div/span/b[text()="{service}"]')
+            else:
+                self.browser.click_element_when_visible(
+                    f'//div[@class="name"]/span[text()="{service}" and @class="dijitComboBoxHighlightMatch"]'
+                )
+
+            self.browser.input_text('//textarea[@data-automation-id="input-description-txndetails"]', description)
+            self.browser.input_text('//input[@data-automation-id="input-rateField"]', str(rate))
+            self.browser.input_text('//input[@data-automation-id="amountField"]', str(rate))
+            index += 1
+
+        total_rate = round(total_rate, 2)
+        processing_fee: bool = first_row.processing_fee
+        if processing_fee:
+            processing_fee_name: str = '3% QuickBooks Processing Fee'
+            self.browser.click_element_when_visible(f'//td[text()="{index}"]')
+            self.wait_element('//input[contains(@id, "ItemComboBox") or @aria-label="ProductService"]')
+            self.browser.input_text(
+                '//input[contains(@id, "ItemComboBox") or @aria-label="ProductService"]',
+                processing_fee_name
+            )
+
+            self.wait_element(f'//div/span/b[text()="{processing_fee_name}"]')
+            self.browser.click_element_when_visible(f'//div/span/b[text()="{processing_fee_name}"]')
+
+            self.browser.input_text(
+                '//input[@data-automation-id="input-rateField"]', str('%.2f' % (total_rate / 0.97 - total_rate))
+            )
+            self.browser.input_text(
+                '//input[@data-automation-id="amountField"]', str('%.2f' % (total_rate / 0.97 - total_rate))
+            )
+
+        self.wait_element('//input[@data-automation-id="input-creation-date-sales"]')
+        self.browser.click_element_when_visible('//input[@data-automation-id="input-creation-date-sales"]')
+
+        estimate_date: str = self.browser.get_value('//input[@data-automation-id="input-creation-date-sales"]')
+        estimate_number: str = '1234'
+        if is_prod:
+            self.browser.click_element_when_visible('//button[text()="Save and send"]')
+            self.wait_element('//button[text()="Send and close"]')
+            estimate_number = self.browser.get_text('//div[@data-qbo-bind="text: referenceNumber"]')
+            self.browser.click_element_when_visible('//button[text()="Send and close"]')
+        else:
+            print('Dev test. The invoice was not saved')
+            self.browser.capture_page_screenshot(
+                os.path.join(
+                    self.output_folder,
+                    f'Test_run-customer_{customer}-{datetime.now().strftime("%H_%M_%S")}.png'
+                )
+            )
+            self.browser.click_element_when_visible('//i[@aria-label="Close"]')
+            self.wait_element('//button[text()="Yes"]', 5)
+            if self.does_element_displayed('//button[text()="Yes"]'):
+                self.browser.click_element_when_visible('//button[text()="Yes"]')
+        self.send_message_estimate_added(first_row.manager,
+                                         first_row.customer,
+                                         estimate_number,
+                                         total_rate,
+                                         )
+
+        return True, estimate_date, estimate_number
